@@ -8,7 +8,7 @@ from django.core.mail.backends.base import BaseEmailBackend
 try:
     from django.utils.module_loading import import_string
 except ImportError:
-    from django.utils.module_loading import import_by_path as import_string
+    from django.utils.module_loading import import_by_path as import_string  # NOQA
 
 
 class EmailBackend(BaseEmailBackend):
